CI script generation
In the future this may get split up into submodules.
Structs
- Github
CiInfo - Info about running dist in Github CI
- Github
CiJob - A custom ci job
- Github
JobStep - A github action workflow step
- Github
JobSteps Builder - Builder for looking up and reporting errors in the steps provided by the
github-build-setupconfiguration - Github
Release Info - Details for github releases
Functions
- runner_
to_ config - Generates a
GithubRunnerConfigfrom a given github runner name