GithubCiInfo

Struct GithubCiInfo 

pub struct GithubCiInfo {
Show 31 fields pub github_ci_workflow_dir: Utf8PathBuf, pub rust_version: Option<String>, pub dist_install_for_coordinator: GhaRunStep, pub dist_install_strategy: DistInstallStrategy, pub fail_fast: bool, pub cache_builds: bool, pub build_local_artifacts: bool, pub dispatch_releases: bool, pub release_branch: Option<String>, pub artifacts_matrix: GithubMatrix, pub pr_run_mode: PrRunMode, pub global_task: GithubGlobalJobConfig, pub tap: Option<String>, pub plan_jobs: Vec<GithubCiJob>, pub local_artifacts_jobs: Vec<GithubCiJob>, pub global_artifacts_jobs: Vec<GithubCiJob>, pub host_jobs: Vec<GithubCiJob>, pub publish_jobs: Vec<String>, pub user_publish_jobs: Vec<GithubCiJob>, pub post_announce_jobs: Vec<GithubCiJob>, pub ssldotcom_windows_sign: Option<ProductionMode>, pub macos_sign: bool, pub hosting_providers: Vec<HostingStyle>, pub tag_namespace: Option<String>, pub root_permissions: Option<GithubPermissionMap>, pub github_build_setup: Vec<GithubJobStep>, pub github_release: Option<GithubReleaseInfo>, pub actions: SortedMap<String, String>, pub need_cargo_auditable: bool, pub need_cargo_cyclonedx: bool, pub need_omnibor: bool,
}
Info about running dist in Github CI

THESE FIELDS ARE LOAD-BEARING because they’re used in the templates.

Fields

github_ci_workflow_dir: Utf8PathBuf

Cached path to github CI workflows dir

rust_version: Option<String>

Version of rust toolchain to install (deprecated)

dist_install_for_coordinator: GhaRunStep

How to install dist when “coordinating” (plan, global build, etc.)

dist_install_strategy: DistInstallStrategy

Our install strategy for dist itself

fail_fast: bool

Whether to fail-fast

cache_builds: bool

Whether to cache builds

build_local_artifacts: bool

Whether to include builtin local artifacts tasks

dispatch_releases: bool

Whether to make CI get dispatched manually instead of by tag

release_branch: Option<String>

Trigger releases on pushes to this branch instead of ci

artifacts_matrix: GithubMatrix

Matrix for upload-local-artifacts

pr_run_mode: PrRunMode

What kind of job to run on pull request

global_task: GithubGlobalJobConfig

global task

tap: Option<String>

homebrew tap

plan_jobs: Vec<GithubCiJob>

plan jobs

local_artifacts_jobs: Vec<GithubCiJob>

local artifacts jobs

global_artifacts_jobs: Vec<GithubCiJob>

global artifacts jobs

host_jobs: Vec<GithubCiJob>

host jobs

publish_jobs: Vec<String>

publish jobs

user_publish_jobs: Vec<GithubCiJob>

user-specified publish jobs

post_announce_jobs: Vec<GithubCiJob>

post-announce jobs

ssldotcom_windows_sign: Option<ProductionMode>

[unstable] whether to add ssl.com windows binary signing

macos_sign: bool

Whether to enable macOS codesigning

hosting_providers: Vec<HostingStyle>

what hosting provider we’re using

tag_namespace: Option<String>

whether to prefix release.yml and the tag pattern

root_permissions: Option<GithubPermissionMap>

Extra permissions the workflow file should have

github_build_setup: Vec<GithubJobStep>

Extra build steps

github_release: Option<GithubReleaseInfo>

Info about making a GitHub Release (if we’re making one)

actions: SortedMap<String, String>

Action versions to use

need_cargo_auditable: bool

Whether to install cargo-auditable

need_cargo_cyclonedx: bool

Whether to run cargo-cyclonedx

need_omnibor: bool

Whether to install and run omnibor-cli

Implementations

Source

impl GithubCiInfo

pub fn new( dist: &DistGraph, ci_config: &GithubCiConfig, ) -> DistResult<GithubCiInfo>

Compute the Github CI stuff

pub fn generate_github_ci(&self, dist: &DistGraph) -> DistResult<String>

Generate the requested configuration and returns it as a string.

pub fn write_to_disk(&self, dist: &DistGraph) -> DistResult<()>

Write release.yml to disk

pub fn check(&self, dist: &DistGraph) -> DistResult<()>

Check whether the new configuration differs from the config on disk writhout actually writing the result.