pub struct GithubJobStep {
pub id: Option<String>,
pub if_expr: Option<Value>,
pub name: Option<String>,
pub uses: Option<String>,
pub run: Option<String>,
pub working_directory: Option<String>,
pub shell: Option<String>,
pub with: BTreeMap<String, Value>,
pub env: BTreeMap<String, Value>,
pub continue_on_error: Option<Value>,
pub timeout_minutes: Option<Value>,
}Expand description
A github action workflow step
Fields
id: Option<String>A step’s ID for looking up any outputs in a later step
if_expr: Option<Value>If this step should run
name: Option<String>The name of this step
uses: Option<String>The identifier for a marketplace action or relative path for a repo hosted action
run: Option<String>A script to run
working_directory: Option<String>The working directory this action should run
shell: Option<String>The shell name to run the run property in e.g. bash or powershell
with: BTreeMap<String, Value>A map of action arguments
env: BTreeMap<String, Value>Environment variables for this step
continue_on_error: Option<Value>If this job should continue if this step errors
timeout_minutes: Option<Value>Maximum number of minutes this step should take