pub struct GithubReleaseInfo {
pub create_release: bool,
pub github_releases_repo: Option<JinjaGithubRepoPair>,
pub external_repo_commit: Option<String>,
pub github_attestations: bool,
pub github_attestations_filters: GithubAttestationsFilters,
pub github_attestations_phase: GithubAttestationsPhase,
pub release_command: String,
pub release_phase: GithubReleasePhase,
}Expand description
Details for github releases
Fields
create_release: boolwhether to create the release or assume an existing one
github_releases_repo: Option<JinjaGithubRepoPair>external repo to release to
external_repo_commit: Option<String>commit to use for github_release_repo
github_attestations: boolWhether to enable GitHub Attestations
github_attestations_filters: GithubAttestationsFiltersPatterns to attest when creating attestations for release artifacts
github_attestations_phase: GithubAttestationsPhaseWhen to generate GitHub Attestations
release_command: Stringgh command to run to create the release
release_phase: GithubReleasePhaseWhich phase to create the release at