pub struct BuildExpectations {
pub packages: SortedMap<String, BinaryExpectations>,
/* private fields */
}Expand description
Output expectations for builds, and computed facts (all packages)
Fields
packages: SortedMap<String, BinaryExpectations>Expectations grouped by package
Implementations
Sourceimpl BuildExpectations
impl BuildExpectations
Sourcepub fn new(dist: &DistGraph, expected_binaries: &[BinaryIdx]) -> Self
pub fn new(dist: &DistGraph, expected_binaries: &[BinaryIdx]) -> Self
Create a new BuildExpectations
Sourcepub fn new_fake(dist: &DistGraph, expected_binaries: &[BinaryIdx]) -> Self
pub fn new_fake(dist: &DistGraph, expected_binaries: &[BinaryIdx]) -> Self
Create a new BuildExpectations, but don’t sweat things being faked
This is used for –artifacts=lies
Sourcepub fn found_bins(&mut self, pkg_id: String, filenames: Vec<Utf8PathBuf>)
pub fn found_bins(&mut self, pkg_id: String, filenames: Vec<Utf8PathBuf>)
Report that a binary was found, which might have been expected
This subroutine is responsible for sorting out whether we care about the binary, and if the maybe_symbols are in fact symbols we care about.
NOTE: it is correct/expected to hand this a bunch of random paths to things that vaguely might be what we want, assuming it knows how to pick the right ones out.
Sourcepub fn process_bins(
&self,
dist: &DistGraph,
manifest: &mut DistManifest,
) -> DistResult<()>
pub fn process_bins( &self, dist: &DistGraph, manifest: &mut DistManifest, ) -> DistResult<()>
Assuming the build is now complete, process the binaries as needed
Currently this is:
- checking src_path was set by found_bin
- computing linkage for the binary
- copying the binary and symbols to their final homes
In the future this may also include:
- code signing / hashing
- stripping