pub enum JinjaInstallPathStrategy {
CargoHome,
HomeSubdir {
subdir: String,
},
EnvSubdir {
env_key: String,
subdir: String,
},
}Expand description
Strategy for install binaries (replica to have different Serialize for jinja)
The serialize/deserialize impls are already required for loading/saving the config from toml/json, and that serialize impl just creates a plain string again. To allow jinja templates to have richer context we have use duplicate type with a more conventional derived serialize.
Variants
CargoHome
install to $CARGO_HOME, falling back to ~/.cargo/
HomeSubdir
install to this subdir of the user’s home
syntax: ~/subdir
EnvSubdir
install to this subdir of this env var
syntax: $ENV_VAR/subdir