pub struct SystemDependencyComplex {
pub version: Option<PackageVersion>,
pub stage: Vec<DependencyKind>,
pub targets: Vec<TripleName>,
}Expand description
Backing type for SystemDependency
Fields
version: Option<PackageVersion>The version to install, as expected by the underlying package manager
stage: Vec<DependencyKind>Stages at which the dependency is required
targets: Vec<TripleName>One or more targets this package should be installed on; defaults to all targets if not specified
Implementations
Sourceimpl SystemDependencyComplex
impl SystemDependencyComplex
Sourcepub fn wanted_for_target(&self, target: &TripleNameRef) -> bool
pub fn wanted_for_target(&self, target: &TripleNameRef) -> bool
Checks if this dependency should be installed on the specified target.
Sourcepub fn stage_wanted(&self, stage: &DependencyKind) -> bool
pub fn stage_wanted(&self, stage: &DependencyKind) -> bool
Checks if this dependency should used in the specified stage.