pub struct GithubHostConfig {
pub common: CommonHostConfig,
pub create: bool,
pub repo: Option<GithubRepoPair>,
pub submodule_path: Option<Utf8PathBuf>,
pub during: GithubReleasePhase,
pub attestations: bool,
pub attestations_filters: GithubAttestationsFilters,
pub attestations_phase: GithubAttestationsPhase,
}Expand description
github host config (final)
Fields
common: CommonHostConfigCommon options
create: boolWhether we should create the Github Release for you
repo: Option<GithubRepoPair>Publish GitHub Releases to this repo instead of the current one
submodule_path: Option<Utf8PathBuf>If github-releases-repo is used, the commit ref to used will be read from the HEAD of the submodule at this path
during: GithubReleasePhaseWhich phase to create the github release in
attestations: boolWhether GitHub Attestations is enabled (default false)
attestations_filters: GithubAttestationsFiltersGitHub Attestation filters (default *)
attestations_phase: GithubAttestationsPhaseWhen to generate GitHub Attestations (default build-local-artifacts)
Implementations
Sourceimpl GithubHostConfig
impl GithubHostConfig
Sourcepub fn defaults_for_workspace(
_workspaces: &WorkspaceGraph,
common: &CommonHostConfig,
) -> Self
pub fn defaults_for_workspace( _workspaces: &WorkspaceGraph, common: &CommonHostConfig, ) -> Self
Get defaults for the given package