pub struct GithubHostLayer {
pub common: CommonHostLayer,
pub create: Option<bool>,
pub repo: Option<GithubRepoPair>,
pub submodule_path: Option<Utf8PathBuf>,
pub during: Option<GithubReleasePhase>,
pub attestations: Option<bool>,
pub attestations_filters: Option<GithubAttestationsFilters>,
pub attestations_phase: Option<GithubAttestationsPhase>,
}Expand description
github host config (raw)
Fields
common: CommonHostLayerCommon options
create: Option<bool>Whether we should create the Github Release for you when you push a tag.
If true (default), dist will create a new Github Release and generate a title/body for it based on your changelog.
If false, dist will assume a draft Github Release already exists with the title/body you want. At the end of a successful publish it will undraft the Github Release.
repo: Option<GithubRepoPair>Publish GitHub Releases to this repo instead of the current one
The user must also set GH_RELEASES_TOKEN in their SECRETS
submodule_path: Option<Utf8PathBuf>If repo is used, the commit ref to used will
be read from the HEAD of the submodule at this path
during: Option<GithubReleasePhase>Which phase to create the github release in
attestations: Option<bool>Whether GitHub Attestations is enabled (default false)
attestations_filters: Option<GithubAttestationsFilters>GitHub Attestation filters (default *)
attestations_phase: Option<GithubAttestationsPhase>When to generate GitHub Attestations (default build-local-artifacts)