pub enum SupportQuality {
HostNative,
BulkyNative,
ImperfectNative,
Emulated,
Hellmulated,
HighwayToHellmulated,
}Expand description
The quality of support an archive provides for a given platform
Variants
HostNative
The archive natively supports this platform, there’s no beating it
BulkyNative
The archive natively supports this platform, but it’s a Universal binary that contains multiple platforms stapled together, so if there are also more precise archives, prefer those.
ImperfectNative
The archive is still technically native to this platform, but it’s in some sense imperfect. This can happen for things like “running a 32-bit binary on 64-bit” or “using a statically linked linux libc”. This solution is acceptable, but a HostNative (or BulkyNative) solution should always be preferred.
Emulated
The archive is only running by the grace of pretty heavyweight emulation like Rosetta2. This should be treated as a last resort, but hey, it works!
Hellmulated
The layers of emulation are out of control.
HighwayToHellmulated
STOP