pub struct LibcVersion {
pub major: u64,
pub series: u64,
}Expand description
A unixy libc version
Fields
major: u64Major version
series: u64Series (minor) version
Implementations
Sourceimpl LibcVersion
impl LibcVersion
Sourcepub fn default_glibc() -> Self
pub fn default_glibc() -> Self
Get the default glibc version for cases where we just need to guess and make one up.
This is the glibc of Ubuntu 22.04, which is the oldest supported github linux runner, as of this writing.