pub struct PlatformSupport {
pub archives: Vec<FetchableArchive>,
pub updaters: Vec<FetchableUpdater>,
pub platforms: SortedMap<TripleName, Vec<PlatformEntry>>,
}Expand description
Computed platform support details for a Release
Fields
archives: Vec<FetchableArchive>The prebuilt archives for the Release
updaters: Vec<FetchableUpdater>The updaters for the Release
platforms: SortedMap<TripleName, Vec<PlatformEntry>>Which options are available for the given target-triples.
The list of PlatformEntries is pre-sorted in descending quality, so the first is the best and should be used if possible (but maybe there’s troublesome RuntimeConditions).
Implementations
Sourceimpl PlatformSupport
impl PlatformSupport
Sourcepub fn fragments(&self) -> Vec<ExecutableZipFragment>
pub fn fragments(&self) -> Vec<ExecutableZipFragment>
Convert to the old-style format so we can gradually migrate
Sourcepub fn conflated_runtime_conditions(&self) -> RuntimeConditions
pub fn conflated_runtime_conditions(&self) -> RuntimeConditions
Conflate all the options that fragments suggests to create a single unified
RuntimeConditions that can be used in installers while we transition to implementations
that more granularly factor in these details.
Sourcepub fn safe_conflated_runtime_conditions(&self) -> RuntimeConditions
pub fn safe_conflated_runtime_conditions(&self) -> RuntimeConditions
Similar to conflated_runtime_conditions, but certain None values are replaced by safe defaults. Currently, a default value is provided for glibc; others may be provided in the future.
Sourcepub fn fill_in_checksums_from_manifest(&mut self, manifest: &DistManifest)
pub fn fill_in_checksums_from_manifest(&mut self, manifest: &DistManifest)
Add checksum information for all archives built so far. They appeared in the manifest after the initial platform support was computed.
Sourcepub fn with_checksums_from_manifest(self, manifest: &DistManifest) -> Self
pub fn with_checksums_from_manifest(self, manifest: &DistManifest) -> Self
A chainable version of Self::fill_in_checksums_from_manifest