pub struct Binary {
pub id: String,
pub pkg_idx: PackageIdx,
pub pkg_id: Option<PackageId>,
pub pkg_spec: String,
pub name: String,
pub file_name: String,
pub target: TripleName,
pub symbols_artifact: Option<ArtifactIdx>,
pub copy_exe_to: Vec<Utf8PathBuf>,
pub copy_symbols_to: Vec<Utf8PathBuf>,
pub features: CargoTargetFeatures,
pub kind: BinaryKind,
}Expand description
A binary we want to build (specific to a Variant)
Fields
id: StringA unique id to use for things derived from this binary
(e.g. my-binary-v1.0.0-x86_64-pc-windows-msvc)
pkg_idx: PackageIdxThe idx of the package this binary is defined by
pkg_id: Option<PackageId>The cargo package this binary is defined by
This is an “opaque” string that will show up in things like cargo machine-readable output, but this is not the format that cargo -p flags expect. Use pkg_spec for that.
pkg_spec: StringAn ideally unambiguous way to refer to a package for the purpose of cargo -p flags.
name: StringThe name of the binary (as defined by the Cargo.toml)
file_name: StringThe filename the binary will have
target: TripleNameThe target triple to build it for
symbols_artifact: Option<ArtifactIdx>The artifact for this Binary’s symbols
copy_exe_to: Vec<Utf8PathBuf>Places the executable needs to be copied to
If this is empty by the time we compute the precise build steps we will determine that this Binary doesn’t actually need to be built.
copy_symbols_to: Vec<Utf8PathBuf>Places the symbols need to be copied to
features: CargoTargetFeaturesfeature flags!
kind: BinaryKindWhat kind of binary this is