pub struct DistGraph {Show 25 fields
pub system_id: SystemId,
pub is_init: bool,
pub allow_dirty: DirtyMode,
pub global_homebrew_tap: Option<String>,
pub global_publishers: Option<PublisherConfig>,
pub precise_cargo_builds: bool,
pub tools: Tools,
pub signer: Signing,
pub templates: Templates,
pub target_dir: Utf8PathBuf,
pub repo_dir: Utf8PathBuf,
pub workspace_dir: Utf8PathBuf,
pub dist_dir: Utf8PathBuf,
pub config: WorkspaceConfig,
pub local_build_steps: Vec<BuildStep>,
pub global_build_steps: Vec<BuildStep>,
pub artifacts: Vec<Artifact>,
pub binaries: Vec<Binary>,
pub variants: Vec<ReleaseVariant>,
pub releases: Vec<Release>,
pub ci: CiInfo,
pub hosting: Option<HostingInfo>,
pub local_builds_are_lies: bool,
pub client_settings: ClientSettings,
pub axoclient: AxoClient,
}Expand description
The graph of all work that dist needs to do on this invocation.
All work is precomputed at the start of execution because only discovering what you need to do in the middle of building/packing things is a mess. It also allows us to report what should happen without actually doing it.
Fields
system_id: SystemIdUnique id for the system we’re building on.
Since the whole premise of dist is to invoke it once on each machine, and no two machines have any reason to have the exact same CLI args for dist, we just use a mangled form of the CLI arguments here.
is_init: boolWhether it looks like dist init has been run
allow_dirty: DirtyModeWhat to allow to be dirty
global_homebrew_tap: Option<String>Homebrew tap all packages agree on
global_publishers: Option<PublisherConfig>builtin publish jobs all packages agree on
precise_cargo_builds: boolWhether we can just build the workspace or need to build each package
tools: ToolsInfo about the tools we’re using to build
signer: SigningSigning tools
templates: TemplatesMinijinja templates we might want to render
target_dir: Utf8PathBufThe cargo target dir.
repo_dir: Utf8PathBufThe root directory of the current git repo
workspace_dir: Utf8PathBufThe root directory of the current cargo workspace.
dist_dir: Utf8PathBufdist’s target dir (generally nested under target_dir).
config: WorkspaceConfigmisc workspace-global config
local_build_steps: Vec<BuildStep>Targets we need to build (local artifacts)
global_build_steps: Vec<BuildStep>Targets we need to build (global artifacts)
artifacts: Vec<Artifact>Distributable artifacts we want to produce for the releases
binaries: Vec<Binary>Binaries we want to build
variants: Vec<ReleaseVariant>Variants of Releases
releases: Vec<Release>Logical releases that artifacts are grouped under
ci: CiInfoInfo about CI backends
hosting: Option<HostingInfo>List of hosting providers to use
local_builds_are_lies: boolLIES ALL LIES
client_settings: ClientSettingsHTTP client settings
axoclient: AxoClientA reusable client for basic http fetches
Implementations
Sourceimpl DistGraph
impl DistGraph
Sourcepub fn artifact(&self, idx: ArtifactIdx) -> &Artifact
pub fn artifact(&self, idx: ArtifactIdx) -> &Artifact
Get a binary
Sourcepub fn release(&self, idx: ReleaseIdx) -> &Release
pub fn release(&self, idx: ReleaseIdx) -> &Release
Get a release
Sourcepub fn variant(&self, idx: ReleaseVariantIdx) -> &ReleaseVariant
pub fn variant(&self, idx: ReleaseVariantIdx) -> &ReleaseVariant
Get a variant