pub struct InstallReceipt {
pub install_prefix: String,
pub install_layout: InstallLayout,
pub binaries: Vec<String>,
pub cdylibs: Vec<String>,
pub cstaticlibs: Vec<String>,
pub source: ReleaseSource,
pub version: String,
pub provider: Provider,
pub binary_aliases: BTreeMap<String, Vec<String>>,
pub modify_path: bool,
}Expand description
Struct representing an install receipt
Fields
install_prefix: StringThe location on disk where this app was installed
install_layout: InstallLayoutThe layout within the above prefix
binaries: Vec<String>A list of all binaries installed by this app
cdylibs: Vec<String>A list of all C dynamic libraries installed by this app
cstaticlibs: Vec<String>A list of all C static libraries installed by this app
source: ReleaseSourceInformation about where to request information on new releases
version: StringThe version that was installed
provider: ProviderThe software which installed this receipt
binary_aliases: BTreeMap<String, Vec<String>>A list of aliases binaries were installed under
modify_path: boolWhether or not to modify system paths when installing
Implementations
Sourceimpl InstallReceipt
impl InstallReceipt
Sourcepub fn from_metadata(
manifest: &DistGraph,
release: &Release,
) -> DistResult<Option<InstallReceipt>>
pub fn from_metadata( manifest: &DistGraph, release: &Release, ) -> DistResult<Option<InstallReceipt>>
Produces an install receipt for the given DistGraph.