pub struct ReleaseVariant {
pub target: TripleName,
pub id: String,
pub binaries: Vec<BinaryIdx>,
pub static_assets: Vec<(StaticAssetKind, Utf8PathBuf)>,
pub local_artifacts: Vec<ArtifactIdx>,
}Expand description
A particular variant of a Release (e.g. “the macos build”)
Fields
target: TripleNameThe target triple this variant is for
id: StringThe unique identifying string used for things related to this variant (e.g. “my-app-v1.0.0-x86_64-pc-windows-msvc”)
binaries: Vec<BinaryIdx>Binaries included in this Release Variant
static_assets: Vec<(StaticAssetKind, Utf8PathBuf)>Static assets that should be included in bundles like archives
local_artifacts: Vec<ArtifactIdx>Artifacts that are “local” to this variant (binaries, symbols, msi-installer…)