pub struct Tools {
pub host_target: TripleName,
pub cargo: Option<CargoInfo>,
pub rustup: Option<Tool>,
pub brew: Option<Tool>,
pub git: Option<Tool>,
pub omnibor: Option<Tool>,
pub code_sign_tool: Option<Tool>,
pub cargo_auditable: Option<Tool>,
pub cargo_cyclonedx: Option<Tool>,
pub cargo_xwin: Option<Tool>,
pub cargo_zigbuild: Option<Tool>,
}Expand description
Various tools we have found installed on the system
Fields
host_target: TripleNameInfo on the host
cargo: Option<CargoInfo>Info on cargo
rustup: Option<Tool>rustup, useful for getting specific toolchains
brew: Option<Tool>homebrew, only available on macOS
git: Option<Tool>git, used if the repository is a git repo
omnibor: Option<Tool>omnibor, used for generating OmniBOR Artifact IDs
code_sign_tool: Option<Tool>ssl.com’s CodeSignTool, for Windows Code Signing
https://www.ssl.com/guide/esigner-codesigntool-command-guide/
cargo_auditable: Option<Tool>cargo-auditable, used for auditable builds
cargo_cyclonedx: Option<Tool>cargo-cyclonedx, for generating CycloneDX artifacts
cargo_xwin: Option<Tool>cargo-xwin, for some cross builds
cargo_zigbuild: Option<Tool>cargo-zigbuild, for some cross builds
Implementations
Sourceimpl Tools
impl Tools
Sourcepub fn cargo(&self) -> DistResult<&CargoInfo>
pub fn cargo(&self) -> DistResult<&CargoInfo>
Returns the cargo info or an error
Sourcepub fn omnibor(&self) -> DistResult<&Tool>
pub fn omnibor(&self) -> DistResult<&Tool>
Returns the omnibor info or an error
Sourcepub fn cargo_auditable(&self) -> DistResult<&Tool>
pub fn cargo_auditable(&self) -> DistResult<&Tool>
Returns cargo-auditable info or an error
Sourcepub fn cargo_cyclonedx(&self) -> DistResult<&Tool>
pub fn cargo_cyclonedx(&self) -> DistResult<&Tool>
Returns cargo-cyclonedx info or an error
Sourcepub fn cargo_xwin(&self) -> DistResult<&Tool>
pub fn cargo_xwin(&self) -> DistResult<&Tool>
Returns cargo-xwin info or an error
Sourcepub fn cargo_zigbuild(&self) -> DistResult<&Tool>
pub fn cargo_zigbuild(&self) -> DistResult<&Tool>
Returns cargo-zigbuild info or an error