Module github

Module github 

CI script generation

In the future this may get split up into submodules.

Structs

GithubCiInfo
Info about running dist in Github CI
GithubCiJob
A custom ci job
GithubJobStep
A github action workflow step
GithubJobStepsBuilder
Builder for looking up and reporting errors in the steps provided by the github-build-setup configuration
GithubReleaseInfo
Details for github releases

Functions

runner_to_config
Generates a GithubRunnerConfig from a given github runner name